@@ -36,12 +36,22 @@ class EthicsFileSerializer(serializers.ModelSerializer):
         return services.create_ethic_file(**validated_data)
 
 
-class UpdateEthicsFileSerializer(EthicsFileSerializer):
-    filename = serializers.CharField()
+class UpdateEthicsFileSerializer(serializers.ModelSerializer):
+    filetype_name = serializers.CharField(source='get_filetype_display', read_only=True)
 
     class Meta:
         model = models.EthicFile
-        fields = 'id', 'ethic', 'filename', 'filetype', 'filetype_name'
+        fields = (
+            'id',
+            'ethic',
+            'filehandle',
+            'filename',
+            'filetype',
+            'filetype_name',
+            'uploaded_at',
+            'uploaded_by',
+        )
+        read_only_fields = 'filehandle',
 
     def update(self, ethics_file, validated_data):
         return services.update_ethic_file(ethics_file, **validated_data)
